;; Copyright 2009, 2019 Kevin Ryde

;; This file is part of aumix-mode.
;;
;; aumix-mode is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the
;; Free Software Foundation; either version 3, or (at your option) any later
;; version.
;;
;; aumix-mode is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
;; more details.
;;
;; You should have received a copy of the GNU General Public License along
;; with aumix-mode; see the file COPYING.  Failing that, go to
;; <http://www.gnu.org/licenses/>.


(defun my-fake-aumix-mode-installed-handler (operation &rest args)
  "Pretend aumix-mode.el is installed."
  (message "my-fake-aumix-mode-installed-handler %S %S" operation args)
  (cond ((eq operation 'file-exists-p)
         t)
        ((eq operation 'expand-file-name)
         ;; absolute filename already, nothing to expand
         (car args))
        (t (error "oops, operation `%S' for aumix-mode installed fakery"
                  operation))))

(defun my-run-test ()
  (let ((count 0))

    (if (not (boundp 'debian-emacs-flavor))
        (message "Skip, not a debian emacs")

      ;;-----------------------------------------------------------------------
      ;; emacsen-startup

      ;; dummy for debian/emacsen-startup under -q -no-site-file
      (unless (fboundp 'debian-pkg-add-load-path-item)
        (defalias 'debian-pkg-add-load-path-item 'identity))

      (let ((file-name-handler-alist
             (append `(("\\`/usr/share/emacs/site-lisp/aumix-mode/"
                        . my-fake-aumix-mode-installed-handler)
                       (,(concat "\\`/usr/share/"
                                 (symbol-name debian-emacs-flavor)
                                 "/site-lisp/aumix-mode/")
                        . my-fake-aumix-mode-installed-handler))
                     file-name-handler-alist)))
        (load (expand-file-name "../debian/emacsen-startup")))
      (setq count (1+ count))

      ;; make sure ahead of debian-pkg-add-load-path-item
      (add-to-list 'load-path (expand-file-name ".."))

      (unless (fboundp 'aumix)
        (error "no aumix autoload"))
      (setq count (1+ count))

      (unless (fboundp 'aumix-mode)
        (error "no aumix-mode autoload"))
      (setq count (1+ count))

      ;;-----------------------------------------------------------------------
      (message "  %d tests" count)
      count)))
